
:orphan:

.. _sphx_glr_auto_examples_sg_execution_times:

Computation times
=================
**06:24.433** total execution time for **auto_examples** files:

- **05:58.846**: :ref:`sphx_glr_auto_examples_example_kim_SW_Si.py` (``example_kim_SW_Si.py``)
- **00:25.587**: :ref:`sphx_glr_auto_examples_example_nn_Si.py` (``example_nn_Si.py``)
